@@ -13,8 +13,10 @@ from leap_model_parser.contract.importmodelresponse import DatasetInfo, NodeResp
 
 layer_attributes_adaptation = {'bias_initializer', 'kernel_initializer'}
 
+
 class KerasJsonModelImport:
-    def __init__(self, custom_layers: Optional[Dict[str, Type[tf.keras.layers.Layer]]] = None, dataset_info: Optional[DatasetInfo] = None) -> None:
+    def __init__(self, custom_layers: Optional[Dict[str, Type[tf.keras.layers.Layer]]] = None,
+                 dataset_info: Optional[DatasetInfo] = None) -> None:
         self.id = 1
         self.nodes_cache: Dict[str, NodeResponse] = defaultdict()
         self.layer_name_to_layer: Dict[str, Dict] = defaultdict()
@@ -150,7 +152,8 @@ class KerasJsonModelImport:
             if layer_json['class_name'] in self.custom_layers:
                 layer_metadata = {
                     'type': 'CustomLayer',
-                    'name': layer_json['class_name']
+                    'class_name': 'CustomLayer',
+                    'selected': layer_json['class_name']
                 }
         return layer_metadata
 
@@ -188,7 +191,7 @@ class KerasJsonModelImport:
             data['arg_names'] = list(lambda_func.__code__.co_varnames)
 
         self.layer_data_adjustments(data, layer_metadata)
-        node = NodeResponse(id=str(self.id), name=layer["class_name"], data=data)
+        node = NodeResponse(id=str(self.id), name=layer_metadata.get("class_name", layer["class_name"]), data=data)
         if 'wrapper' in layer:
             node.wrapper = layer['wrapper']
         self.nodes_cache[node_key] = node
@@ -215,6 +218,8 @@ class KerasJsonModelImport:
                 layer_config[layer_attribute] = layer_config[layer_attribute]['class_name']
 
         layer_config["type"] = layer_metadata.get('type')
+        if 'selected' in layer_metadata:
+            layer_config["selected"] = layer_metadata['selected']
         # TODO: remove this hard coded condition after support
         if layer_config.get('return_state'):
             raise Exception(f"{layer_metadata.get('name')} layer with return_state True is not supported,"
@@ -251,7 +256,8 @@ class KerasJsonModelImport:
                 connection_format = f"{node.id}-feature_map"
         elif _is_dataset_node(node):
             inputs = _get_dataset_inputs_from_dataset_node(node)
-            has_dataset_but_no_input_is_match = self.dataset_info is not None and not any(input_data['name'] == node_input_layer['name'] for input_data in inputs)
+            has_dataset_but_no_input_is_match = self.dataset_info is not None and not any(
+                input_data['name'] == node_input_layer['name'] for input_data in inputs)
             if has_dataset_but_no_input_is_match:
                 return None
             connection_format = f"{node.id}-{node_input_layer['name']}"
@@ -286,7 +292,7 @@ class KerasJsonModelImport:
             layer['config'] = gru_config
         return layer
 
-    def get_and_add_dataset_node_if_not_existed(self) -> NodeResponse : 
+    def get_and_add_dataset_node_if_not_existed(self) -> NodeResponse:
         datasetNode = self.nodes_cache.get('Dataset')
         if datasetNode is None:
             dataset_copy = copy.deepcopy(DATASET_DATA)
@@ -319,15 +325,19 @@ def _add_origin_name_to_nodes(nodes: Dict[str, NodeResponse]):
             node.data["origin_name"] = node.data["name"]
             node.data.pop("name")
 
+
 def _is_dataset_node(node: NodeResponse) -> bool:
     return node.name == 'Dataset'
 
+
 def _is_represntaion_block_node(node: NodeResponse) -> bool:
     return node.name == 'Representation Block'
 
+
 def _get_dataset_inputs_from_dataset_node(node: NodeResponse):
     return node.data['datasetVersion']['metadata']['setup']['inputs']
 
+
 DATASET_DATA = {'datasetVersion': {'metadata': {'setup': {'preprocess': {'training_length': 0, 'validation_length': 0},
                                                           'inputs': [], 'metadata': [], 'outputs': [],
                                                           'visualizers': [], 'prediction_types': [],
